@@ -3,14 +3,18 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+# WARNING: do not import unnecessary things here to keep cli startup time under
+# control
 import logging
 
 import click
 
-from swh.core.cli import CONTEXT_SETTINGS, AliasedGroup
+from swh.core.cli import CONTEXT_SETTINGS, AliasedGroup, swh as swh_cli_group
 
 
-@click.group(name="scheduler", context_settings=CONTEXT_SETTINGS, cls=AliasedGroup)
+@swh_cli_group.group(
+    name="scheduler", context_settings=CONTEXT_SETTINGS, cls=AliasedGroup
+)
 @click.option(
     "--config-file",
     "-C",
@@ -45,7 +49,7 @@ def cli(ctx, config_file, database, url, no_stdout):
             pass
 
     from swh.core import config
-    from swh.scheduler import get_scheduler, DEFAULT_CONFIG
+    from swh.scheduler import DEFAULT_CONFIG, get_scheduler
 
     ctx.ensure_object(dict)
 
